@@ -1,3 +1,4 @@
+import collections
 import hashlib
 import inspect
 import json
@@ -7,7 +8,6 @@ import typing
 import urllib.parse
 from abc import ABCMeta
 from collections import OrderedDict, defaultdict
-from collections.abc import Hashable
 from decimal import Decimal
 from enum import Enum
 from typing import DefaultDict, Generic, List, Optional, Type, TypeVar, Union
@@ -84,7 +84,7 @@ def is_field(obj):
 
 
 def is_basic_type(obj, allow_none=True):
-    if not isinstance(obj, Hashable):
+    if not isinstance(obj, collections.abc.Hashable):
         return False
     if not allow_none and (obj is None or obj is OpenApiTypes.NONE):
         return False
@@ -446,7 +446,7 @@ def follow_field_source(model, path):
         )
 
     def dummy_property(obj) -> str:
-        pass
+        pass  # pragma: no cover
     return dummy_property
 
 
@@ -735,6 +735,51 @@ def modify_for_versioning(patterns, method, path, view, requested_version):
     return path
 
 
+def analyze_named_regex_pattern(path):
+    """ safely extract named groups and their pattern from given regex pattern """
+    result = {}
+    stack = 0
+    name_capture, name_buffer = False, ''
+    regex_capture, regex_buffer = False, ''
+    i = 0
+    while i < len(path):
+        # estimate state at position i
+        skip = False
+        if path[i] == '\\':
+            ff = 2
+        elif path[i:i + 4] == '(?P<':
+            skip = True
+            name_capture = True
+            ff = 4
+        elif path[i] in '(':
+            stack += 1
+            ff = 1
+        elif path[i] == '>' and name_capture:
+            assert name_buffer
+            name_capture = False
+            regex_capture = True
+            skip = True
+            ff = 1
+        elif path[i] in ')':
+            if regex_capture and not stack:
+                regex_capture = False
+                result[name_buffer] = regex_buffer
+                name_buffer, regex_buffer = '', ''
+            else:
+                stack -= 1
+            ff = 1
+        else:
+            ff = 1
+        # fill buffer based on state
+        if name_capture and not skip:
+            name_buffer += path[i:i + ff]
+        elif regex_capture and not skip:
+            regex_buffer += path[i:i + ff]
+        i += ff
+    assert not stack
+    return result
+
+
 def detype_pattern(pattern):
     """
     return an equivalent pattern that accepts arbitrary values for path parameters.
@@ -763,8 +808,14 @@ def detype_pattern(pattern):
             is_endpoint=pattern._is_endpoint
         )
     elif isinstance(pattern, RegexPattern):
+        detyped_regex = pattern._regex
+        for name, regex in analyze_named_regex_pattern(pattern._regex).items():
+            detyped_regex = detyped_regex.replace(
+                f'(?P<{name}>{regex})',
+                f'(?P<{name}>[^/]+)',
+            )
         return RegexPattern(
-            regex=re.sub(r'\(\?P<(\w+)>.+?\)', r'(?P<\1>[^/]+)', pattern._regex),
+            regex=detyped_regex,
             name=pattern.name,
             is_endpoint=pattern._is_endpoint
         )
@@ -821,8 +872,21 @@ def camelize_operation(path, operation):
 
 
 def build_mock_request(method, path, view, original_request, **kwargs):
+    """ build a mocked request and use original request as reference if available """
     request = getattr(APIRequestFactory(), method.lower())(path=path)
     request = view.initialize_request(request)
+    if original_request:
+        request.user = original_request.user
+        request.auth = original_request.auth
+        # ignore headers related to authorization as it has been handled above.
+        # also ignore ACCEPT as the MIME type refers to SpectacularAPIView and the
+        # version (if available) has already been processed by SpectacularAPIView.
+        for name, value in original_request.META.items():
+            if not name.startswith('HTTP_'):
+                continue
+            if name in ['HTTP_ACCEPT', 'HTTP_COOKIE', 'HTTP_AUTHORIZATION']:
+                continue
+            request.META[name] = value
     return request
 
 
@@ -863,9 +927,16 @@ def resolve_type_hint(hint):
 
     if origin is None and is_basic_type(hint, allow_none=False):
         return build_basic_type(hint)
+    elif origin is None and inspect.isclass(hint) and issubclass(hint, tuple):
+        # a convoluted way to catch NamedTuple. suggestions welcome.
+        if typing.get_type_hints(hint):
+            properties = {k: resolve_type_hint(v) for k, v in typing.get_type_hints(hint).items()}
+        else:
+            properties = {k: build_basic_type(OpenApiTypes.ANY) for k in hint._fields}
+        return build_object_type(properties=properties, required=properties.keys())
     elif origin is list or hint is list:
         return build_array_type(
-            resolve_type_hint(args[0]) if args else build_basic_type(OpenApiTypes.OBJECT)
+            resolve_type_hint(args[0]) if args else build_basic_type(OpenApiTypes.ANY)
         )
     elif origin is tuple:
         return build_array_type(
@@ -903,5 +974,7 @@ def resolve_type_hint(hint):
         if type(None) in args:
             schema['nullable'] = True
         return schema
+    elif origin is collections.abc.Iterable:
+        return build_array_type(resolve_type_hint(args[0]))
     else:
         raise UnableToProceedError()
