@@ -67,7 +67,10 @@ class SpectacularAPIView(APIView):
             return self._get_schema_response(request)
 
     def _get_schema_response(self, request):
-        generator = self.generator_class(urlconf=self.urlconf, api_version=self.api_version)
+        # version specified as parameter to the view always takes precedence. after
+        # that we try to source version through the schema view's own versioning_class.
+        version = self.api_version or request.version
+        generator = self.generator_class(urlconf=self.urlconf, api_version=version)
         return Response(generator.get_schema(request=request, public=self.serve_public))
 
 
@@ -157,6 +160,9 @@ class SpectacularRedocView(APIView):
         schema_url = self.url or get_relative_url(reverse(self.url_name, request=request))
         schema_url = set_query_parameters(schema_url, lang=request.GET.get('lang'))
         return Response(
-            {'schema_url': schema_url},
+            data={
+                'dist': spectacular_settings.REDOC_DIST,
+                'schema_url': schema_url,
+            },
             template_name=self.template_name
         )
