@@ -10,9 +10,10 @@ from rest_framework.decorators import action, api_view
 from rest_framework.schemas import AutoSchema as DRFAutoSchema
 from rest_framework.views import APIView
 
-from drf_spectacular.generators import SchemaGenerator
 from drf_spectacular.types import OpenApiTypes
-from drf_spectacular.utils import PolymorphicProxySerializer, extend_schema, extend_schema_view
+from drf_spectacular.utils import (
+    OpenApiParameter, PolymorphicProxySerializer, extend_schema, extend_schema_view,
+)
 from tests import generate_schema
 from tests.models import SimpleModel, SimpleSerializer
 
@@ -20,7 +21,6 @@ from tests.models import SimpleModel, SimpleSerializer
 def test_serializer_name_reuse(capsys):
     from rest_framework import routers
 
-    from drf_spectacular.generators import SchemaGenerator
     router = routers.SimpleRouter()
 
     def x1():
@@ -45,8 +45,7 @@ def test_serializer_name_reuse(capsys):
 
     router.register('x2', X2Viewset, basename='x2')
 
-    generator = SchemaGenerator(patterns=router.urls)
-    generator.get_schema(request=None, public=True)
+    generate_schema(None, patterns=router.urls)
 
     stderr = capsys.readouterr().err
     assert 'Encountered 2 components with identical names "X" and different classes' in stderr
@@ -251,8 +250,7 @@ def test_operation_id_collision_resolution(capsys):
         path('pi/<int:foo>', view_func),
         path('pi/', view_func),
     ]
-    generator = SchemaGenerator(patterns=urlpatterns)
-    schema = generator.get_schema(request=None, public=True)
+    schema = generate_schema(None, patterns=urlpatterns)
 
     assert schema['paths']['/pi/']['get']['operationId'] == 'pi_retrieve'
     assert schema['paths']['/pi/{foo}']['get']['operationId'] == 'pi_retrieve_2'
@@ -327,3 +325,35 @@ def test_warning_request_body_not_resolvable(capsys):
     generate_schema('x', view_function=view_func)
     stderr = capsys.readouterr().err
     assert 'could not resolve request body for POST /x' in stderr
+
+
+def test_response_header_warnings(capsys):
+    @extend_schema(
+        request=OpenApiTypes.ANY,
+        responses=OpenApiTypes.ANY,
+        parameters=[OpenApiParameter(name='test', response=True)]
+    )
+    @api_view(['POST'])
+    def view_func(request, format=None):
+        pass  # pragma: no cover
+
+    generate_schema('x', view_function=view_func)
+    stderr = capsys.readouterr().err
+    assert 'incompatible location type ignored' in stderr
+
+
+def test_unknown_base_field_warning(capsys):
+    class UnknownField(serializers.Field):
+        pass
+
+    class XSerializer(serializers.Serializer):
+        field = UnknownField()
+
+    @extend_schema(request=XSerializer, responses=XSerializer)
+    @api_view(['POST'])
+    def view_func(request, format=None):
+        pass  # pragma: no cover
+
+    generate_schema('x', view_function=view_func)
+    stderr = capsys.readouterr().err
+    assert 'could not resolve serializer field' in stderr
